@@ -62,10 +62,6 @@ class TestBuild(unittest.TestCase):
 
     def test_get_files(self):
 
-        paths = get_files('/tmp/test_fab_build/test.txt')
-        expected = ['/tmp/test_fab_build/test.txt']
-        self.assertItemsEqual(paths, expected)
-
         paths = get_files(dict(path='/tmp/test_fab_build/', recursive=False))
         expected = ['/tmp/test_fab_build/test.txt',
                     '/tmp/test_fab_build/test.py',
